@@ -1,6 +1,6 @@
 import unittest
 
-from hashbase.crc8 import CRC8
+from hashbase import CRC8
 
 
 class TestCRC8Strings(unittest.TestCase):
